cfmDataSumm: Summarising data within a Counter Factual Model (CFM)

View source: R/cfmDataSumm.R

cfmDataSummR Documentation

Summarising data within a Counter Factual Model (CFM)

Description

The pscCFM creates a model object which is stripped of identifiable information. The cfmDataSumm function supplies a tabulated form of the dataset used in the CFM for summary information. Information returned in the form of a table

Usage

cfmDataSumm(cfm)

Arguments

cfm

a 'glm' or 'flexsurvreg' model object

Value

a summary table


psc documentation built on June 8, 2026, 5:06 p.m.