Learn R Programming

psc (version 2.0.0)

cfmDataVis: Visualising data within a CFM

Description

The pscCFM creates a model object which is stripped of identifiable information. The cfmDataVis function supplies a visualised form of the dataset for summary information

Usage

cfmDataVis(cfm)

Value

a list of grobs for each model covariate

Arguments

cfm

a 'glm' or 'flexsurvreg' model object