coef.psc: Returns the coefficient estimate of a psc object.

View source: R/coef.psc.R

coef.pscR Documentation

Returns the coefficient estimate of a psc object.

Description

Returns basic measures of the posterior distribution obtained from the psc object

Usage

## S3 method for class 'psc'
coef(object, ...)

Arguments

object

a 'psc' object

...

not used

Value

The summary of the posterior distribution for the efficacy parameter in terms of the median and 95


psc documentation built on June 8, 2026, 5:06 p.m.