A generated model with a count data endpoint and a log link function. Data for the model were synthetically generated and are based on a dataset to evaulate the use of Sorafenib in HCC akin to the PROSASH model (see ?psc::surv.mod for more details)
count.modA model of class 'glm':
ECOG performance Status
AFP - log scale
albumin
Creatinine - log scale