| gemCFM | R Documentation |
A generated model with a survival endpoint and a cuymulative hazard function estimated using flexible parametric splines. Data for the model were obtained from the ESPAC-3 trials
gemCFM
A model of class 'pscCFM' containg a 'flexsurvreg' model:
cumulative baseline hazard parameters
negative (n=1) or positive (n=2) lymph nodes
tumour grade (1,2 or 3)
log transformed ca19.9
Resection Margins)
simulated
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.