| init | R Documentation |
Function for estimating initial parameter values
init(pscOb)
pscOb |
a psc object |
This function takes the likelihood and data structures provided by the pscData() strucutres and fits the likelihood to provide starting values for MCMC estimation
Parameter Estimates and standard error for the efficacy parameter
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.