A function which defines the likelihood for a PSC model where the Counter Factual Model (CFM) takes the form of a 'flexsurvreg' object and an efficacy parameter (\(\beta\)) is being estimated. For more details on fitting please see ?pscfit and ?pscEst
lik.flexsurvreg(beta, pscOb)the results of a likelihood functions
a parameter to be estimate
A pscOb object containing a cleaned dataset including covariates to match the CFM
A likelihood function for use by pscfit for a model of class 'flexsurvreg'