modp: modp

View source: R/modp.R

modpR Documentation

modp

Description

A function which rrturns either the input value (if positive) or zero (if negative)

Usage

modp(x)

Arguments

x

a numberic vector

Details

A fucntion which returns a version of x with negative values replacd with 0

Value

a numeric vector with negative values replaced with 0


psc documentation built on June 8, 2026, 5:06 p.m.