View source: R/plot.psc.binary.R
| plot.psc.binary | R Documentation |
A function which illsutrates the predicted response under the counter factual model and the observed response under the experimental treatment(s).
## S3 method for class 'psc.binary'
plot(pscOb, ...)
pscOb |
an object of class 'psc' |
... |
not used |
This function plots the expected response of the control treatment along with the observe response rates of the experimental arms
a survival plot corresponding to the psc fit
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.