plot.psc.cont: Function for Plotting PSC objects

View source: R/plot.psc.cont.R

plot.psc.contR Documentation

Function for Plotting PSC objects

Description

A function which illsutrates the predicted response under the counter factual model and the observed response under the experimental treatment(s).

Usage

## S3 method for class 'psc.cont'
plot(x, ...)

Arguments

x

an object of class 'psc'

...

not used

Details

This function plots the expected response of the control treatment along with the observe response rates of the experimental arms

Value

a survival plot corresponding to the psc fit


psc documentation built on June 8, 2026, 5:06 p.m.