plot.psc.count: Function for Plotting PSC objects #' A function which...

View source: R/plot.psc.count.R

plot.psc.countR Documentation

Function for Plotting PSC objects #' A function which illsutrates the predicted response under the counter factual model and the observed response under the experimental treatment(s).

Description

Function for Plotting PSC objects #' A function which illsutrates the predicted response under the counter factual model and the observed response under the experimental treatment(s).

Usage

## S3 method for class 'psc.count'
plot(x, ...)

Arguments

x

an object of class 'psc'

...

not used

Details

This function plots the expected response of the control treatment along with the observe response rates of the experimental arms

Value

a survival plot corresponding to the psc fit


psc documentation built on June 8, 2026, 5:06 p.m.