| pscData | R Documentation |
This function ensures the data are supplied in a structure which allows for estimation. This is performed by re-fitting the original CFM with the DC and extracting the appropriate structures. Data are returned in terms of "Y" for model outcomes, "X" for data and "Z" for random effects where mixed models are supplied.
pscData(CFM, DC, id = NULL, trt = NULL)
CFM |
a Counter Factual Model |
DC |
a Data Cohort object |
id |
to be specified for subgroup analysis. Defaults to NULL |
trt |
to be specified for multiple treatment comparisons. Defaults to NULL |
A set of structures for use with estimation procedures
e4_data <- psc::e4_data
gemCFM <- psc::gemCFM
pscOb <- pscData(gemCFM,e4_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.