pscData_addLik: A function that add a likelihood for estimation to the...

View source: R/pscData_addLik.R

pscData_addLikR Documentation

A function that add a likelihood for estimation to the pscObject

Description

The purpose of this function is to include the appropriate likelihood to the psc object for estimation procedures

Usage

pscData_addLik(CFM)

Arguments

CFM

A counter factual model

Value

a likelihood function


psc documentation built on June 8, 2026, 5:06 p.m.