View source: R/pscData_addtrt.R
| pscData_addtrt | R Documentation |
The purpose of this function is to organise a treatment indicator where multiple treatment comparisons are being evaluated. This acts as a sub-function to the pscData.R function.
pscData_addtrt(DC, trt)
DC |
a data cohort to be 'cleaned' |
trt |
a treatment indicator |
a dataset which is checked and compatible with the CFM
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.