View source: R/pscData_match.R
| pscData_match | R Documentation |
The purpose of this function is to run a series of checks to ensure that the data included in the data cohort is comparable to the counter-factual model. This matches the data classes and checks the levels in the DC match those used in the CFM. This acts as a sub-function to the pscData.R function.
pscData_match(cls, lev, DC)
cls |
a list of extracted data classes |
lev |
a list of factor levels |
DC |
a data cohort to be 'cleaned' |
a dataset which is checked and compatible with the CFM
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.