pscData_miss: A function which removes missing data from the DC

View source: R/pscData_miss.R

pscData_missR Documentation

A function which removes missing data from the DC

Description

Currently the psc package works only on complete-case datasets. This function removes rows with missing data and returns a warning to inform the user. This acts as a sub-function to the pscData.R function.

Usage

pscData_miss(DC)

Arguments

DC

a data cohort to be 'cleaned'

Value

a dataset with missing data removed


psc documentation built on June 8, 2026, 5:06 p.m.