Learn R Programming

psc (version 2.0.0)

pscEst_samp: Starting conditions for Bayesian MCMC estimation procedures in 'pscfit' A procedure which runs the sampling process for MCMC estimation

Description

Starting conditions for Bayesian MCMC estimation procedures in 'pscfit' A procedure which runs the sampling process for MCMC estimation

Usage

pscEst_samp(pscOb, nsim)

Value

An updated set of attributes for the pscOb which includes

Arguments

pscOb

an pscOb object which has been passed through pscData() and init() functions

nsim

the number of MCMC simulations to run