pscEst_update: Updating the posterior distribution as part of the MCMC...

View source: R/pscEst_update.R

pscEst_updateR Documentation

Updating the posterior distribution as part of the MCMC estimation process A procedure which performs a single update of the posterior distribution

Description

Updating the posterior distribution as part of the MCMC estimation process A procedure which performs a single update of the posterior distribution

Usage

pscEst_update(i, draws, pscOb)

Arguments

i

index of the draw number (i>1)

draws

a matrix containing the posterior draws to update

pscOb

an pscOb object which has been passed through pscData() and init() functions

Value

An updated set of posterior draws


psc documentation built on June 8, 2026, 5:06 p.m.