Learn R Programming

psc (version 2.0.0)

visComp: Visualising Comparisons between a CFM and a DC

Description

The visComp function takes the data visualisations supplied as part of the CFM model and appends summaries of the equivalent datapoints from the Data Cohort.

Usage

visComp(CFM, DC, id = NULL)

Value

a list of grobs for each model covariate

Arguments

CFM

an object of class pscCFM

DC

A dataset including columns to match to covariates in the model

id

Numeric vector stating which patient(s) from the dataset should be included in the analysis. Defaults to all patients