A generated model with a binary endpoint and a logistic link function. Data for the model were synthetically generated and are based on a dataset to evaulate the use of Sorafenib in HCC akin to the PROSASH model (see ?psc::surv.mod for more details)
bin.modA model of class 'glm':
vascular invasion
ECOG performance Status
AFP - log scale
albumin
Creatinine - log scale
metastesis