Learn R Programming

psc (version 2.0.0)

cfmDataSumm: Summarising data within a Counter Factual Model (CFM)

Description

The pscCFM creates a model object which is stripped of identifiable information. The cfmDataSumm function supplies a tabulated form of the dataset used in the CFM for summary information. Information returned in the form of a table

Usage

cfmDataSumm(cfm)

Value

a summary table

Arguments

cfm

a 'glm' or 'flexsurvreg' model object