powered by
The pscCFM creates a model object which is stripped of identifiable information. The cfmDataVis function supplies a visualised form of the dataset for summary information
cfmDataVis(cfm)
a list of grobs for each model covariate
a 'glm' or 'flexsurvreg' model object