Learn R Programming

psc (version 2.0.0)

coef.psc: Returns the coefficient estimate of a psc object.

Description

Returns basic measures of the posterior distribution obtained from the psc object

Usage

# S3 method for psc
coef(object, ...)

Value

The summary of the posterior distribution for the efficacy parameter in terms of the median and 95

Arguments

object

a 'psc' object

...

not used