Learn R Programming

psc (version 2.0.0)

plot.psc.cont: Function for Plotting PSC objects

Description

A function which illsutrates the predicted response under the counter factual model and the observed response under the experimental treatment(s).

Usage

# S3 method for psc.cont
plot(x, ...)

Value

a survival plot corresponding to the psc fit

Arguments

x

an object of class 'psc'

...

not used

Details

This function plots the expected response of the control treatment along with the observe response rates of the experimental arms