Learn R Programming

psc (version 2.0.0)

plotCFM: Function for Plotting PSC objects

Description

A function which visualises the data of a CFM or the combined CFM and DC data for a 'psc' obecjec

Usage

plotCFM(x, ...)

Value

a plot to describe the data included in the models

Arguments

x

an object of class 'CFM' or 'psc'

...

not used

Details

This function returns either density plots (continuous data) or bar plots (categroical data) to describe the data in the CFM. If an object is supplied which has combied the CFM and DC (e.g. a psc object or an object which has been passed through pscData()) then a comparison of the CFM and DC will be supplied

Examples

Run this code
e4_data <- psc::e4_data
gemCFM <- psc::gemCFM
plotCFM(gemCFM)
psc <- pscfit(gemCFM,e4_data,nsim=2000,nchain=1)
plotCFM(psc)

Run the code above in your browser using DataLab