A function which visualises the data of a CFM or the combined CFM and DC data
for a 'psc' obecjec
Usage
plotCFM(x, ...)
Value
a plot to describe the data included in the models
Arguments
x
an object of class 'CFM' or 'psc'
...
not used
Details
This function returns either density plots (continuous data) or
bar plots (categroical data) to describe the data in the CFM. If an object
is supplied which has combied the CFM and DC (e.g. a psc object or an object
which has been passed through pscData()) then a comparison of the CFM and DC
will be supplied