Learn R Programming

psc (version 2.0.0)

postSummary: Posterior Summary

Description

A function that provides a summary of the posterior distributions obtained from a pscEst() procedures

Usage

postSummary(pscOb, thin = 2, burn = 1000, par = "beta")

Value

Returns a summary of a 'psc' object including details on the original Counter Factual Model, a summary of the Data Cohort, the predicted responses from the CFM and details on the model fit.

Arguments

pscOb

a pscOb function which has passed through pscEst()

thin

a thin to be applied to the posterior distributions

burn

a burnin to ba applied to the posterior distribution

par

the parameter to be summarised - defaults to 'beta' to summarise all 'beta' parameters in the posterior distribution

Details

This function makes use of the 'posterior' package to pull together each of the 'draw' matrices included in the psc object and produce posterior summaries

Examples

Run this code
e4_data <- psc::e4_data
gemCFM <- psc::gemCFM
pscOb <- pscData(gemCFM,e4_data)
pscOb <- init(pscOb)
pscOb <- pscEst(pscOb)
pscOb <- postSummary(pscOb)

Run the code above in your browser using DataLab