A function that provides a summary of the posterior distributions obtained
from a pscEst() procedures
Usage
postSummary(pscOb, thin = 2, burn = 1000, par = "beta")
Value
Returns a summary of a 'psc' object including details on the original
Counter Factual Model, a summary of the Data Cohort, the predicted responses
from the CFM and details on the model fit.
Arguments
pscOb
a pscOb function which has passed through pscEst()
thin
a thin to be applied to the posterior distributions
burn
a burnin to ba applied to the posterior distribution
par
the parameter to be summarised - defaults to 'beta' to summarise
all 'beta' parameters in the posterior distribution
Details
This function makes use of the 'posterior' package to pull together
each of the 'draw' matrices included in the psc object and produce posterior
summaries