pscComb: PSC Estiamtion combination

View source: R/pscComb.R

pscCombR Documentation

PSC Estiamtion combination

Description

This function allows the combination of estimation where mulitple treatment comparisons are being made and one of the treatment levels relates to the control level. Note here it is assumed that the control level is coded trt=0. This function then combines the two efficacy estimates for the treatment effect (concurrent and synhtetic) whilst accounting for the correlation inherent in these two estimates.

Usage

pscComb(x)

Arguments

x

A pscfit object with 2 treatment comparions


psc documentation built on June 8, 2026, 5:06 p.m.