View source: R/pscData_addLik.R
| pscData_addLik | R Documentation |
The purpose of this function is to include the appropriate likelihood to the psc object for estimation procedures
pscData_addLik(CFM)
CFM |
A counter factual model |
a likelihood function
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.