Learn R Programming

psc (version 2.0.0)

pscData_addtrt: A function that includes a treatment indicator when multiple treatment comparisons are required

Description

The purpose of this function is to organise a treatment indicator where multiple treatment comparisons are being evaluated. This acts as a sub-function to the pscData.R function.

Usage

pscData_addtrt(DC, trt)

Value

a dataset which is checked and compatible with the CFM

Arguments

DC

a data cohort to be 'cleaned'

trt

a treatment indicator