The purpose of this function is to organise a treatment indicator where multiple treatment comparisons are being evaluated. This acts as a sub-function to the pscData.R function.
pscData_addtrt(DC, trt)a dataset which is checked and compatible with the CFM
a data cohort to be 'cleaned'
a treatment indicator