View source: R/pscData_error.R
| pscData_error | R Documentation |
The purpose of this function is check that terms included in the Data Cohort match those used within the Counter Factual Model. This acts as a sub-function to the pscData.R function.
pscData_error(term.nm, DC)
term.nm |
Term names from the CFM |
DC |
a data cohort to be 'cleaned' |
a 'stop' command when errors are detected
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.