Learn R Programming

psc (version 2.0.0)

pscData_error: A function which performs error checks between the DC and CFM

Description

The purpose of this function is check that terms included in the Data Cohort match those used within the Counter Factual Model. This acts as a sub-function to the pscData.R function.

Usage

pscData_error(term.nm, DC)

Value

a 'stop' command when errors are detected

Arguments

term.nm

Term names from the CFM

DC

a data cohort to be 'cleaned'