The purpose of this function is to run a series of checks to ensure that the data included in the data cohort is comparable to the counter-factual model. This matches the data classes and checks the levels in the DC match those used in the CFM. This acts as a sub-function to the pscData.R function.
pscData_match(cls, lev, DC)a dataset which is checked and compatible with the CFM
a list of extracted data classes
a list of factor levels
a data cohort to be 'cleaned'