Learn R Programming

psc (version 2.0.0)

pscData_miss: A function which removes missing data from the DC

Description

Currently the psc package works only on complete-case datasets. This function removes rows with missing data and returns a warning to inform the user. This acts as a sub-function to the pscData.R function.

Usage

pscData_miss(DC)

Value

a dataset with missing data removed

Arguments

DC

a data cohort to be 'cleaned'