pscData_miss: A function which removes missing data from the DC
Description
Currently the psc package works only on complete-case datasets. This
function removes rows with missing data and returns a warning to inform the
user. This acts as a sub-function to the pscData.R function.