pscEst_start: Starting conditions for Bayesian MCMC estimation procedures in 'pscfit'
A procedure which sets the starting conditions for MCMC estimation
Description
Starting conditions for Bayesian MCMC estimation procedures in 'pscfit'
A procedure which sets the starting conditions for MCMC estimation
Usage
pscEst_start(pscOb, nsim, nchain)
Value
An updated set of attributes for the pscOb which includes
Arguments
pscOb
an pscOb object which has been passed through pscData() and
init() functions
nsim
the number of MCMC simulations to run
nchain
Number of chains to use for analysis
Details
A procedure which sets the starting conditions for MCMC estimation including
defining starting estimates, setting a matrix for draws to be save in and
defining, target and prior distributions and deifnign the posterior
desitribution from the CFM. This also sets the number of cores to be used
for estimation where parallel computing is applied.