View source: R/pscEst_update.R
| pscEst_update | R Documentation |
Updating the posterior distribution as part of the MCMC estimation process A procedure which performs a single update of the posterior distribution
pscEst_update(i, draws, pscOb)
i |
index of the draw number (i>1) |
draws |
a matrix containing the posterior draws to update |
pscOb |
an pscOb object which has been passed through pscData() and init() functions |
An updated set of posterior draws
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.