Learn R Programming

psc (version 2.0.0)

pscEst_update: Updating the posterior distribution as part of the MCMC estimation process A procedure which performs a single update of the posterior distribution

Description

Updating the posterior distribution as part of the MCMC estimation process A procedure which performs a single update of the posterior distribution

Usage

pscEst_update(i, draws, pscOb)

Value

An updated set of posterior draws

Arguments

i

index of the draw number (i>1)

draws

a matrix containing the posterior draws to update

pscOb

an pscOb object which has been passed through pscData() and init() functions