Updating the posterior distribution as part of the MCMC estimation process A procedure which performs a single update of the posterior distribution
pscEst_update(i, draws, pscOb)An updated set of posterior draws
index of the draw number (i>1)
a matrix containing the posterior draws to update
an pscOb object which has been passed through pscData() and init() functions