A function to estimate the survival function based on parameter estimates - used in ootstrapping CFM for CIs
spline_surv_est(lam, kn, k, haz_co, cov_co, cov = cov, tm = tm, beta = 0)A data frame containing survival estimates for a give time
parameters of the flexible spline model
knots included in the flexible spline model
number of knots in the flexible spline model
parameters for the baseline hazard function in the flexible spline model
covariate parameters of the flexible spline model
a matrix of covaraites from the Data Cohort
time at which to assess the survival function
parameter with which to adjust the baseline function (defaults to beta=0)