The visComp function takes the data visualisations supplied as part of the CFM model and appends summaries of the equivalent datapoints from the Data Cohort.
visComp(CFM, DC, id = NULL)a list of grobs for each model covariate
an object of class pscCFM
A dataset including columns to match to covariates in the model
Numeric vector stating which patient(s) from the dataset should be included in the analysis. Defaults to all patients